[LinuxBIOS] PATCH: IT8671F fixes.

Uwe Hermann uwe at hermann-uwe.de
Sat Aug 19 21:29:50 CEST 2006


Hi,

here's a bunch of fixes for the IT8671F Super IO. 


HTH, Uwe.
-- 
Uwe Hermann 
http://www.hermann-uwe.de
http://www.it-services-uh.de  | http://www.crazy-hacks.org 
http://www.holsham-traders.de | http://www.unmaintained-free-software.org
-------------- next part --------------
Index: src/superio/ite/it8671f/superio.c
===================================================================
--- src/superio/ite/it8671f/superio.c	(Revision 2381)
+++ src/superio/ite/it8671f/superio.c	(Arbeitskopie)
@@ -33,8 +33,7 @@
 	conf = dev->chip_info;
 
 	switch (dev->path.u.pnp.device) {
-	case IT8671F_FDC:
-		/* TODO. */
+	case IT8671F_FDC: /* TODO. */
 		break;
 	case IT8671F_SP1:
 		res0 = find_resource(dev, PNP_IDX_IO0);
@@ -44,11 +43,15 @@
 		res0 = find_resource(dev, PNP_IDX_IO0);
 		init_uart8250(res0->base, &conf->com2);
 		break;
+	case IT8671F_PP: /* TODO. */
+		break;
 	case IT8671F_KBCK:
 		res0 = find_resource(dev, PNP_IDX_IO0);
 		res1 = find_resource(dev, PNP_IDX_IO1);
 		init_pc_keyboard(res0->base, res1->base, &conf->keyboard);
 		break;
+	case IT8671F_KBCM: /* TODO. */
+		break;
 	}
 }
 
@@ -60,12 +63,10 @@
 	.init             = init,
 };
 
-/* TODO: Find and check datasheet. */
+/* TODO: FDC, PP, KBCM. */
 static struct pnp_info pnp_dev_info[] = {
- { &ops, IT8671F_FDC,  PNP_IO0 | PNP_IRQ0 | PNP_DRQ0, { 0x07fa, 0}, },
- /* { &ops, IT8671F_PP,   PNP_IO0 | PNP_IRQ0 | PNP_DRQ0, { 0x04f8, 0}, }, */
+ { &ops, IT8671F_SP1,  PNP_IO0 | PNP_IRQ0, { 0x7f8, 0 }, },
  { &ops, IT8671F_SP2,  PNP_IO0 | PNP_IRQ0 | PNP_DRQ0 | PNP_DRQ1, { 0x7f8, 0 }, },
- { &ops, IT8671F_SP1,  PNP_IO0 | PNP_IRQ0, { 0x7f8, 0 }, },
  { &ops, IT8671F_KBCK, PNP_IO0 | PNP_IO1 | PNP_IRQ0, { 0x7f8, 0 }, { 0x7f8, 0x4}, },
 };
 
Index: src/superio/ite/it8671f/it8671f.h
===================================================================
--- src/superio/ite/it8671f/it8671f.h	(Revision 2381)
+++ src/superio/ite/it8671f/it8671f.h	(Arbeitskopie)
@@ -16,11 +16,10 @@
  * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301 USA
  */
 
-/* TODO: Find datasheet and check for correct values. */
 #define IT8671F_FDC  0x00 /* Floppy */
-/* #define IT8671F_PP   0x01 */ /* Parallel port */
+#define IT8671F_SP1  0x01 /* Com1 */
 #define IT8671F_SP2  0x02 /* Com2 */
-#define IT8671F_SP1  0x03 /* Com1 */
-#define IT8671F_KBCK 0x06 /* Keyboard */
-/* #define IT8671F_FAN  0x09 */
+#define IT8671F_PP   0x03 /* Parallel port */
+#define IT8671F_KBCK 0x05 /* Keyboard */
+#define IT8671F_KBCM 0x06 /* Mouse */
 
-------------- next part --------------
A non-text attachment was scrubbed...
Name: signature.asc
Type: application/pgp-signature
Size: 189 bytes
Desc: Digital signature
URL: <http://www.coreboot.org/pipermail/coreboot/attachments/20060819/1248b6a8/attachment.sig>


More information about the coreboot mailing list
Index: src/superio/ite/it8671f/it8671f_early_serial.c
===================================================================
--- src/superio/ite/it8671f/it8671f_early_serial.c	(Revision 2381)
+++ src/superio/ite/it8671f/it8671f_early_serial.c	(Arbeitskopie)
@@ -20,18 +20,18 @@
 #include "it8671f.h"
 
 /* The base address is 0x3f0, 0x3bd, or 0x370, depending on config bytes. */
-#define SIO_BASE  0x3f0
-#define SIO_INDEX SIO_BASE
-#define SIO_DATA  SIO_BASE+1
+#define SIO_BASE                    0x3f0
+#define SIO_INDEX                   SIO_BASE
+#define SIO_DATA                    SIO_BASE+1
 
-/* TODO: These values are actually from the IT8673F datasheet; check if
-   they're also valid for the IT8671F. */
-#define IT8671F_CONFIG_REG_CC       0x02 /* Configure Control. */
-#define IT8671F_CONFIG_REG_LDN      0x07 /* Logical Device Number. */
-#define IT8671F_CONFIG_REG_CLOCKSEL 0x23 /* Clock Selection. */
-#define IT8671F_CONFIG_REG_SWSUSP   0x24 /* Software Suspend. */
+/* Global Configuration Registers. */
+#define IT8671F_CONFIG_REG_CC      0x02   /* Configure Control (write-only). */
+#define IT8671F_CONFIG_REG_LDN     0x07   /* Logical Device Number. */
+#define IT8671F_CONFIG_REG_LDE     0x23   /* PnP Logical Device Enable. */
+#define IT8671F_CONFIG_REG_SWSUSP  0x24   /* Software Suspend. */
 
-#define IT8671F_ADDRESS_PORT        0x279
+#define IT8671F_CONFIGURATION_PORT 0x0279 /* Write-only. */
+#define IT8671F_WRITE_DATA_PORT    0x0A79 /* Write-only. */
 
 /* Special values used for entering MB PnP mode. The first four bytes of
  * each line determine the address port, the last four are data. */
@@ -42,7 +42,7 @@
 	0xe8, 0x74, 0x3a, 0x9d, /**/ 0xce, 0xe7, 0x73, 0x39,
 };
 
-/* The content of IT8671F_CONFIG_REG_LDN (index 07h) must be set to the
+/* The content of IT8671F_CONFIG_REG_LDN (index 0x07) must be set to the
  * LDN the register belongs to, before you can access the register. */
 static void it8671f_sio_write(uint8_t ldn, uint8_t index, uint8_t value)
 {
@@ -63,10 +63,10 @@
 	/* Base address 0x3f0: 0x86 0x80 0x55 0x55. */
 	/* Base address 0x3bd: 0x86 0x80 0x55 0xaa. */
 	/* Base address 0x370: 0x86 0x80 0xaa 0x55. */
-	outb(0x86, IT8671F_ADDRESS_PORT);
-	outb(0x80, IT8671F_ADDRESS_PORT);
-	outb(0x55, IT8671F_ADDRESS_PORT);
-	outb(0x55, IT8671F_ADDRESS_PORT);
+	outb(0x86, IT8671F_CONFIGURATION_PORT);
+	outb(0x80, IT8671F_CONFIGURATION_PORT);
+	outb(0x55, IT8671F_CONFIGURATION_PORT);
+	outb(0x55, IT8671F_CONFIGURATION_PORT);
 
 	/* Sequentially write the 32 special values. */
 	for (i = 0; i < 32; i++) {
@@ -75,14 +75,20 @@
 
 	/* (2) Modify the data of configuration registers. */
 
-	/* Enable parallel port, serial port 1, serial port 2, floppy. */
-	it8671f_sio_write(0x00, 0x23, 0x0f);
+	/* Allow all devices to be enabled. Bits: FDC (0), Com1 (1), Com2 (2),
+           PP (3), Reserved (4), KBCK (5), KBCM (6), Reserved (7). */
+	it8671f_sio_write(0x00, IT8671F_CONFIG_REG_LDE, 0x6f);
 
-	/* Activate serial port 1 and 2. */
-	it8671f_sio_write(0x01, 0x30, 0x1);
-	it8671f_sio_write(0x02, 0x30, 0x1);
+	/* Activate all devices. */  
+	it8671f_sio_write(IT8671F_FDC,  0x30, 0x01); /* Floppy */
+	it8671f_sio_write(IT8671F_SP1,  0x30, 0x01); /* Serial port 1 */
+	it8671f_sio_write(IT8671F_SP2,  0x30, 0x01); /* Serial port 2 */
+	it8671f_sio_write(IT8671F_PP,   0x30, 0x01); /* Parallel port */
+	it8671f_sio_write(IT8671F_KBCK, 0x30, 0x01); /* Keyboard */
+	it8671f_sio_write(IT8671F_KBCM, 0x30, 0x01); /* Mouse */
 
-	/* Select 24MHz CLKIN and clear software suspend mode. */
+	/* Select 24MHz CLKIN (clear bit 6) and clear software suspend
+	   mode (clear bit 0). */
 	it8671f_sio_write(0x00, IT8671F_CONFIG_REG_SWSUSP, 0x00);
 
 	/* (3) Exit the configuration state (MB PnP mode). */